@@ -18,19 +18,28 @@ import warnings as _warnings
 _warnings.simplefilter("ignore")
 _qtapp = None
 
+# Import databox first
+from . import _data      as data
+from . import _functions as fun
 from . import _settings
 settings = _settings.settings()
+fun._settings  = settings
+data._settings = settings
+
 
 def _warn(*args):
+    if settings['ignore_warnings']: return
+
     args = list(args)
-    if not settings['ignore_warnings']:
-        print('\nWarning:', args.pop(0))
-        for a in args: print('  ', a)
-        print("To disable warnings, set spinmob.settings['ignore_warnings']=True")
+    print('\nWarning:', args.pop(0))
+    for a in args: print('  ', a)
+    print("To disable warnings, set spinmob.settings['ignore_warnings']='True'")
 
 
 try:
-    import pyqtgraph    as _pyqtgraph
+    import pyqtgraph as _pyqtgraph
+    if _pyqtgraph.__version__[0:4] == '0.10': _warn('Spinmob requires pyqtgraph version 0.11 or higher. Previous versions are no longer supported.')
+
     _qtc = _pyqtgraph.Qt.QtCore
     _qt  = _pyqtgraph.Qt
     _qtw = _pyqtgraph.Qt.QtGui
@@ -43,7 +52,7 @@ try:
     _qtapp.setAttribute(_qtc.Qt.AA_EnableHighDpiScaling, True)
 
 except:
-    _warn("pyqtgraph version 0.10 or higher is required (use a conda or pip install).")
+    _warn("pyqtgraph version 0.11 or higher is required (use a conda or pip install) if you wish to use dialogs or egg.")
 
     _qtc = None
     _qt  = None
@@ -60,10 +69,8 @@ if _sys.version[0] == '2':
 
 
 from . import _plot           as plot        ; plot._settings    = settings
-from . import _data           as data        ; data._settings    = settings
 from . import _dialogs        as dialogs     ; dialogs._settings = settings
 from . import _pylab_tweaks   as tweaks      ; tweaks._settings  = settings
-from . import _functions      as fun         ; fun._settings     = settings
 
 plot.tweaks._pylab_colormap._settings = settings
 
